# Concepts

Background knowledge for understanding MCPower's approach to power analysis.

```{toctree}
:maxdepth: 1

effect-sizes
variable-types
correlations
scenario-analysis
mixed-effects
performance
```
